==> haskell-dependent-sum-template-0.1.0.3-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.0.3
visibility:           public
id:                   dependent-sum-template-0.1.0.3-9ZC4OD2YFYbE0krPCE5pQC
key:                  dependent-sum-template-0.1.0.3-9ZC4OD2YFYbE0krPCE5pQC
license:              LicenseRef-PublicDomain
maintainer:           Ryan Trinkle <ryan.trinkle@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  48f31782977b7ffad63b8bab36f84b1a
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/dependent-sum-template-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/dependent-sum-template-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/dependent-sum-template-0.1.0.3

hs-libraries:         HSdependent-sum-template-0.1.0.3-9ZC4OD2YFYbE0krPCE5pQC
depends:
    base-4.15.0.0 dependent-sum-0.7.1.0-KdJzumxrn7t6qK9jgfy9Bn
    template-haskell-2.17.0.0
    th-abstraction-0.4.2.0-DYHW6JC9drp3AaDf8Ov8bI
    th-extras-0.0.0.4-4Wg8haLg5vaLPv6Jma6ccx

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-template-0.1.0.3-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum-template
version:              0.1.0.3
visibility:           public
id:                   dependent-sum-template-0.1.0.3-3QsQ8nkk2mz5BRGVAIfONV
key:                  dependent-sum-template-0.1.0.3-3QsQ8nkk2mz5BRGVAIfONV
license:              LicenseRef-PublicDomain
maintainer:           Ryan Trinkle <ryan.trinkle@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  1b04d73d12525dd13b84660561908fae
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/dependent-sum-template-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/dependent-sum-template-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/dependent-sum-template-0.1.0.3

hs-libraries:         HSdependent-sum-template-0.1.0.3-3QsQ8nkk2mz5BRGVAIfONV
depends:
    base-4.15.0.0 dependent-sum-0.7.1.0-A1FKN1VL2AyEHIVw2VCxMN
    template-haskell-2.17.0.0
    th-abstraction-0.4.2.0-DYHW6JC9drp3AaDf8Ov8bI
    th-extras-0.0.0.4-Dg0goSPNCbf7Eg43mfV2Jc

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
